# Cambrian Tools

To execute [master_run.sh](master_run.sh) just run the following command in the terminal:
```bash
bash master_run.sh
```

```bash
pip freeze > requirements.txt
conda env export > environment.yml
```
